#
# spec file for package python-natsort
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-natsort
Version:        6.0.0
Release:        2.8
Summary:        Natural sorting in Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/SethMMorton/natsort
Source:         https://files.pythonhosted.org/packages/source/n/natsort/natsort-%{version}.tar.gz
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  python-rpm-macros
BuildRequires:  python2-pathlib
Requires:       python-setuptools
Recommends:     python-PyICU >= 1.0.0
Recommends:     python-fastnumbers >= 2.0.0
BuildArch:      noarch
%ifpython2
Requires:       python2-pathlib
%endif
%python_subpackages

%description
Natsort provides a function natsorted that helps sort lists
"naturally" ("naturally" is rather ill-defined, but in general it means
sorting based on meaning and not computer code point).

%prep
%setup -q -n natsort-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

export PYTHONPATH=%{buildroot}%{python3_sitelib}
help2man -o natsort.1 -N %{buildroot}%{_bindir}/natsort
install -Dm0644 natsort.1 %{buildroot}%{_mandir}/man1/natsort.1

%check
export LANG=en_US.UTF8
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
pytest-%{$python_bin_suffix}
}

%files %{python_files}
%license LICENSE
%doc README.rst CHANGELOG.rst
%python3_only %{_mandir}/man1/natsort.1%{ext_man}
%python3_only %{_bindir}/natsort
%{python_sitelib}/natsort*

%changelog
* Sun Feb 10 2019 arun@gmx.de
- specfile:
  * update copyright year
- update to version 6.0.0:
  * Drop support for Python 2.6 and 3.3 (thanks @jdufresne) (issue
    [#70])
  * Remove deprecated APIs (kwargs number_type, signed, exp, as_path,
    py3_safe; enums ns.TYPESAFE, ns.DIGIT, ns.VERSION; functions
    versorted, index_versorted) (issue #81)
  * Remove pipenv as a dependency for building (issue #86)
  * Simply Travis-CI configuration (thanks @jdufresne) (issue #88)
  * Fix README rendering in PyPI (thanks @altendky) (issue #89)
* Thu Nov 22 2018 arun@gmx.de
- specfile:
  * added CHANGELOG.rst
- update to version 5.5.0:
  * Formally deprecated old or misleading APIs (issue #83)
  * Documentation, packaging, and CI cleanup (thanks @jdufresne)
    (issues #69, #71-#80)
  * Consolidate API documentation into a single page (issue #82)
  * Add a CHANGELOG.rst to the top-level of the repository (issue #85)
  * Add back support for very old versions of setuptools (issue #84)
* Sun Sep 16 2018 arun@gmx.de
- update to version 5.4.1:
  * Fix error in a newly added test.
  * Changed code format and quality checking infrastructure.
* Sat Sep  8 2018 arun@gmx.de
- specfile:
  * be more specific in %%files section
- update to version 5.4.0:
  * Re-expose natsort_key as "public" and remove the associated
    DepricationWarning.
  * Add better developer documentation.
  * Refactor tests.
  * Bump allowed fastnumbers version.
* Wed Aug 29 2018 tchvatal@suse.com
- Make sure tests pass in python 3.7
* Sun Jul  8 2018 arun@gmx.de
- update to version 5.3.3:
  * Update docs with a FAQ and quick how-it-works.
  * Fix a StopIteration error in the testing code.
  * Enable Python 3.7 support in Travis-CI.
* Wed May 23 2018 tchvatal@suse.com
- Version set the requires based on setup.py
* Mon May 21 2018 arun@gmx.de
- specfile:
  * added setuptools as a requirements
* Mon May 21 2018 arun@gmx.de
- update to version 5.3.2:
  * Fix bug that prevented install on old versions of setuptools.
  * Revert layout from src/natsort/ back to natsort/ to make user
    testing simpler.
* Tue May 15 2018 arun@gmx.de
- update to version 5.3.1:
  * No bugfixes or features, just infrastructure and installation
    updates.
  * Move to defining dependencies with Pipfile.
  * Development layout is now src/natsort/ instead of natsort/.
  * Add bumpversion infrastructure.
  * Extras can be installed by "[]" notation.
* Sat Apr 21 2018 arun@gmx.de
- update to version 5.3.0:
  * Fix bug in assessing fastnumbers version at import-time.
  * Add ability to consider unicode-decimal numbers as numbers.
* Thu Mar  1 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 5.2.0:
  * Add ns.NUMAFTER to cause numbers to be placed after non-numbers.
  * Add natcmp function (Python 2 only).
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 5.1.0
  * See changelog at https://github.com/SethMMorton/natsort/blob/5.1.0/docs/source/changelog.rst
* Tue Feb  3 2015 toddrme2178@gmail.com
- Update to 3.5.2
  - Enhancement that will convert a 'pathlib.Path' object to a 'str' if
    'ns.PATH' is enabled.
- Update to 3.5.1
  - Fixed bug that caused list/tuples to fail when using 'ns.LOWECASEFIRST'
    or 'ns.IGNORECASE'.
  - Refactored modules so that only the public API was in natsort.py and
    ns_enum.py.
  - Refactored all import statements to be absolute, not relative.
- Update to 3.5.0
  - Added the 'alg' argument to the 'natsort' functions.  This argument
    accepts an enum that is used to indicate the options the user wishes
    to use.  The 'number_type', 'signed', 'exp', 'as_path', and 'py3_safe'
    options are being depreciated and will become (undocumented)
    keyword-only options in natsort version 4.0.0.
  - The user can now modify how 'natsort' handles the case of non-numeric
    characters.
  - The user can now instruct 'natsort' to use locale-aware sorting, which
    allows 'natsort' to perform true "human sorting".
  - The `humansorted` convenience function has been included to make this
    easier.
  - Updated shell script with locale functionality.
- Update to 3.4.1
  - 'natsort' will now use the 'fastnumbers' module if it is installed. This
    gives up to an extra 30%% boost in speed over the previous performance
    enhancements.
  - Made documentation point to more 'natsort' resources, and also added a
    new example in the examples section.
- Update to 3.4.0
  - Fixed a bug that caused user's options to the 'natsort_key' to not be
    passed on to recursive calls of 'natsort_key'.
  - Added a 'natsort_keygen' function that will generate a wrapped version
    of 'natsort_key' that is easier to call.  'natsort_key' is now set to
    depreciate at natsort version 4.0.0.
  - Added an 'as_path' option to 'natsorted' & co. that will try to treat
    input strings as filepaths. This will help yield correct results for
    OS-generated inputs like
    ``['/p/q/o.x', '/p/q (1)/o.x', '/p/q (10)/o.x', '/p/q/o (1).x']``.
  - Massive performance enhancements for string input (1.8x-2.0x), at the expense
    of reduction in speed for numeric input (~2.0x).
  - This is a good compromise because the most common input will be strings,
    not numbers, and sorting numbers still only takes 0.6x the time of sorting
    strings.  If you are sorting only numbers, you would use 'sorted' anyway.
  - Added the 'order_by_index' function to help in using the output of
    'index_natsorted' and 'index_versorted'.
  - Added the 'reverse' option to 'natsorted' & co. to make it's API more
    similar to the builtin 'sorted'.
  - Added more unit tests.
  - Added auxillary test code that helps in profiling and stress-testing.
  - Reworked the documentation, moving most of it to PyPI's hosting platform.
  - Added support for coveralls.io.
  - Entire codebase is now PyFlakes and PEP8 compliant.
- Implement update-alternatives for upcoming python 3 version.
* Sat Jul 12 2014 boris@steki.net
- initial packaging of 3.3.0 version
